@@ -18,14 +18,6 @@ class InteligerMeta(type):
     _instance: Optional[Inteliger] = None
 
     def __call__(self) -> Inteliger:
-        """
-        :Nome da classe/função: __call__
-        :descrição: Função que sobrescreve as chamadas para a classe e verifica se já existe uma instância da classe existente no servidor,
-                    se não houver, cria, se houver, us a existente
-        :Criação: Nícolas Marinoni Grande - 17/08/2020
-        :Edições:
-        :return: Instância para ser usada
-        """
         if self._instance is None:
             self._instance = super().__call__()
         return self._instance
